"""
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
P3D script : DeleteEmptyGeometryLayers2022_0.py
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Script Target : 
|~----------------------------------------------------------------------------~|

 This script affects : geometry layers

|~----------------------------------------------------------------------------~|

Compatible Versions : 
|~----------------------------------------------------------------------------~|

 This script is compatible with versions :  2022.2 X1 ALPHA // 2022.0 

|~----------------------------------------------------------------------------~|


Requirements : 
|~----------------------------------------------------------------------------~|

 Must have .P3D project (CurrentP3DSession)

 Special conditions : None

|~----------------------------------------------------------------------------~|



Description :
|~----------------------------------------------------------------------------~|

 This script deletes all empty geometry layers.

|~----------------------------------------------------------------------------~|


Usage:
|~----------------------------------------------------------------------------~|
 
 Classic use case in P3D :  Scripting/Execute Script -> choose script

|~----------------------------------------------------------------------------~|

Data output format :
|~----------------------------------------------------------------------------~|

 A console message will indicate that empty layer(s) have been removed.  

|~----------------------------------------------------------------------------~|

"""
from p3dsdk import *

def delete_layer_if_empty(layer: GeometryLayer):
    sub_layers = layer.list_child_layers(recursive=False)
    for s in sub_layers:
        delete_layer_if_empty(s)

    have_surfaces = len(layer.list_surfaces()) > 0
    have_sub_layers = len(layer.list_child_layers(recursive=False)) > 0

    # Delete the layer if it contains no surfaces and no sub_layers
    # (they are already deleted if they were empty)
    if not have_surfaces and not have_sub_layers:
        layer.remove(True)

with CurrentP3DSession(fallback_port=33900) as p3d:
    model = p3d.data.list_models()[0]  # Get the first model
    layers = model.list_geometry_layers(recursive=False)
    layer_deleted = 0
    for layer in layers:
        delete_layer_if_empty(layer)
    print("Empty layer(s) deleted!\n")
